@@ -4,17 +4,17 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef KGAPI2_CALENDAR_FREEBUSYQUERYJOB_H
-#define KGAPI2_CALENDAR_FREEBUSYQUERYJOB_H
+#pragma once
 
 #include "fetchjob.h"
 #include "kgapicalendar_export.h"
 
-#include <QVector>
 #include <QDateTime>
+#include <QList>
 #include <QScopedPointer>
 
-namespace KGAPI2 {
+namespace KGAPI2
+{
 
 class KGAPICALENDAR_EXPORT FreeBusyQueryJob : public KGAPI2::FetchJob
 {
@@ -23,8 +23,10 @@ public:
     struct BusyRange {
         BusyRange() = default;
         BusyRange(const QDateTime &busyStart, const QDateTime &busyEnd)
-            : busyStart(busyStart), busyEnd(busyEnd)
-        {}
+            : busyStart(busyStart)
+            , busyEnd(busyEnd)
+        {
+        }
 
         bool operator==(const BusyRange &other) const
         {
@@ -34,20 +36,16 @@ public:
         QDateTime busyStart;
         QDateTime busyEnd;
     };
-    using BusyRangeList = QVector<BusyRange>;
+    using BusyRangeList = QList<BusyRange>;
 
-    explicit FreeBusyQueryJob(const QString &id,
-                              const QDateTime &timeMin,
-                              const QDateTime &timeMax,
-                              const AccountPtr &account,
-                              QObject* parent = nullptr);
+    explicit FreeBusyQueryJob(const QString &id, const QDateTime &timeMin, const QDateTime &timeMax, const AccountPtr &account, QObject *parent = nullptr);
     ~FreeBusyQueryJob() override;
 
-    QString id() const;
-    QDateTime timeMin() const;
-    QDateTime timeMax() const;
+    [[nodiscard]] QString id() const;
+    [[nodiscard]] QDateTime timeMin() const;
+    [[nodiscard]] QDateTime timeMax() const;
 
-    BusyRangeList busy() const;
+    [[nodiscard]] BusyRangeList busy() const;
 
 protected:
     void start() override;
@@ -58,9 +56,6 @@ private:
     class Private;
     QScopedPointer<Private> const d;
     friend class Private;
-
 };
 
 }
-
-#endif // KGAPI2_CALENDAR_FREEBUSYQUERYJOB_H
